*** Inequality and the Partisan Political Economy - Replication Package ***
** Brendan Connell, Dalton Dorr, & Adrian Shin **
***************************************************************
***************************************************************

//Cross-National Data File Name
use "Cross National.dta"

**** Cross-National Analyses ****

/** Figure 1 **/
twoway (scatter top1is year if ccode==2 & year>=1900, connect(l l) sort(year) yscale(range(0 25)) ylabel(0(5)25) ytitle("Top 1% Income Share") lcolor(gs10) lpattern(solid) msymbol(t) mcolor(gs10) msize(small)) (scatter top1is year if ccode==740 & year>=1900, connect(l l) sort(year) lcolor(gs10) lpattern(solid) lwidth(thick) msymbol(i)) (scatter top1is year if ccode==210 & year>=1900, connect(l l) sort(year) lcolor(gs10) lpattern(dash) lwidth(thick) msymbol(i))  (scatter top1is year if ccode==220 & year>=1900, connect(l l) sort(year) lcolor(gs4) lpattern(solid) msymbol(d) mcolor(gs4) msize(vsmall)) (scatter top1is year if ccode==200 & year>=1900, connect(l l) sort(year) lcolor(gs4) lpattern(dash) lwidth(medthick) msymbol(i)) (line top1is year if ccode==380 & year>=1900,connect(l l) sort(year) lcolor(gs3) lpattern(solid) msymbol(i)), xtitle(Year) xlabel(1900(20)2000) title("") graphregion(fcolor(white) lcolor(white)) legend(row(2) lab(1 "United States") lab(2 "Japan") lab(3 "Netherlands") lab(4 "France") lab(5 "United Kingdom") lab(6 "Sweden"))

/** Table 1 & Figure 2**/
/* Model 1 */
xtpcse  topitaxrate2 topitaxrate2l1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Figure 2a*/
qui margins, dydx(top1isl1) at(leftexec2l1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist leftexec2l1 if leftexec2l1==0 | leftexec2l1==1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) yscale(axis(1) range(-.6(.2).4)) yline(0) ylabel(-.6(.2).4,axis(1)) xlab(0 "Non-Leftist" 1 "Leftist") xscale(range(-.25 1.25)) barwidth(.25)) plot1opts(color(black)) ci1opts(lc(black)) yline(0) xtitle("") ytitle("") title("") xscale(range(-0.5 1.5)) recast(scatter) legend(off) graphregion(fcolor(white) lcolor(white))

/* Figure A1a */
qui margins, dydx(leftexec2l1) at(top1isl1=(6(2)22)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top1isl1 if top1isl1<22 & top1isl1>6 & topitaxrate2l1!=., yaxis(2) xscale(range(6(2)22)) yscale(range(-.5(2)8)) yline(0) ylabel(0(2)8,axis(1)) yscale(axis(2) range(0 .21) off) lc(white%0) fcolor(gs10%25) xlabel(6(2)22) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) legend(off) xtitle(Top 1% Share of Income, size(med)) xtitle("Top 1% Income Share") ytitle("") title("") graphregion(fcolor(white) lcolor(white))

/* Model 2 */
xtpcse  top_incrate_n top_incrate_nl1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Figure 2b */
qui margins, dydx(top1isl1) at(leftexec2l1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist leftexec2l1 if leftexec2l1==0 | leftexec2l1==1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) yscale(axis(1) range(-.6(.2).4)) yline(0) ylabel(-.6(.2).4,axis(1)) xlab(0 "Non-Leftist" 1 "Leftist") xscale(range(-.25 1.25)) barwidth(.25)) plot1opts(color(black)) ci1opts(lc(black)) yline(0) xtitle("") ytitle("") title("") xscale(range(-0.5 1.5)) recast(scatter) legend(off) graphregion(fcolor(white) lcolor(white))

/* Figure A1b */
qui margins, dydx(leftexec2l1) at(top1isl1=(6(2)22)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top1isl1 if top1isl1<22 & top1isl1>6 & top_incrate_nl1!=., yaxis(2) xscale(range(6(2)22)) yscale(range(-.5(.1)1)) yscale(axis(2) range(0 .21) off) xlabel(6(2)22) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) legend(off) yline(0) xtitle(Top 1% Share of Income, size(med)) xtitle("Top 1% Income Share") ytitle("") title("") graphregion(fcolor(white) lcolor(white))

*** Time Period Analyses ***

/** Table A3 **/
/* Model A1 */
xtpcse topitaxrate2 topitaxrate2l1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A2 */
xtreg  topitaxrate2 topitaxrate2l1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & year<1946, cluster(ccode)

/* Model A3 */
xtreg  topitaxrate2 topitaxrate2l1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & year>1945 & year<1971, cluster(ccode)

/* Model A4 */
xtreg  topitaxrate2 topitaxrate2l1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & year>1971, cluster(ccode)


/** Table A4 **/
/* Model A5 */
xtpcse top_incrate_n top_incrate_nl1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A6 */
xtreg  top_incrate_n top_incrate_nl1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & year<1946, cluster(ccode)

/* Model A7 */
xtreg  top_incrate_n top_incrate_nl1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & year>1945 & year<1972, cluster(ccode)

/* Model A8 */
xtreg  top_incrate_n top_incrate_nl1 c.leftexec2l1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 & year>1971, cluster(ccode)


*** Legislative Partisanship ***

/** Table A5 **/
/* Model A9 */
xtpcse  topitaxrate2 topitaxrate2l1 c.gov_left3l1##c.top1isl1 unisuffragel1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A10 */
xtpcse  top_incrate_n top_incrate_nl1 c.gov_left3l1##c.top1isl1 unisuffragel1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1


*** Center-Left Parties ***

/** Table A6 **/
/* Model A11 */
xtpcse topitaxrate2 topitaxrate2l1 c.centerleftl1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A12 */
xtpcse top_incrate_n top_incrate_nl1 c.centerleftl1##c.top1isl1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1


*** POLITY ***

/** Table A7 **/
/* Model A13 */
xtpcse  topitaxrate2 topitaxrate2l1 c.leftexec2l1##c.top1isl1 polity2l1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1

/* Model A14 */
xtpcse  top_incrate_n top_incrate_nl1 c.leftexec2l1##c.top1isl1 polity2l1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1


/** Table A8 & Figure A2 **/

/* Model A16 */
xtpcse  topitaxrate2 topitaxrate2l1 c.top10isl1##c.leftexec2l1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Figure A2a */
qui margins, dydx(top10isl1) at(leftexec2l1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist leftexec2l1 if leftexec2l1==0 | leftexec2l1==1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) yscale(axis(1) range(-.25(.1).3)) yline(0) ylabel(-.2(.1).3,axis(1)) xlab(0 "Non-Leftist" 1 "Leftist") xscale(range(-.25 1.25)) barwidth(.25)) plot1opts(color(black)) ci1opts(lc(black)) yline(0) xtitle("") ytitle("") title("") xscale(range(-0.5 1.5)) recast(scatter) legend(off) graphregion(fcolor(white) lcolor(white))

/* Figure A3a */
qui margins, dydx(leftexec2l1) at(top10isl1=(26(2)48)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10isl1 if top10isl1<48 & top10isl1>26 & topitaxrate2l1!=., yaxis(2) xscale(range(26(2)48)) yscale(range(-1(2)8)) yline(0) ylabel(0(2)8) yscale(axis(2) range(0 .21) off) xlabel(26(2)48) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) legend(off) xtitle("Top 10% Income Share") ytitle("") title("") graphregion(fcolor(white) lcolor(white))


/* Model A18 */
xtpcse top_incrate_n top_incrate_nl1 c.top10isl1##c.leftexec2l1 unisuffragel1 himobpopyear2pl1 rgdppcl1 i.ccode i.year australiatrend austriatrend belgiumtrend canadatrend denmarktrend finlandtrend francetrend germanytrend irelandtrend italytrend japantrend koreatrend netherlandstrend newzealandtrend norwaytrend swedentrend switzerlandtrend uktrend usatrend if independence==1 

/* Figure A2b */
qui margins, dydx(top10isl1) at(leftexec2l1=(0 1)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist leftexec2l1 if leftexec2l1==0 | leftexec2l1==1, fcolor(none) lc(ltblue) yaxis(2) yscale(axis(2) off) yscale(axis(1) range(-.25(.1).3)) yline(0) ylabel(-.2(.1).3,axis(1)) xlab(0 "Non-Leftist" 1 "Leftist") xscale(range(-.25 1.25)) barwidth(.25)) plot1opts(color(black)) ci1opts(lc(black)) yline(0) xtitle("") ytitle("") title("") xscale(range(-0.5 1.5)) recast(scatter) legend(off) graphregion(fcolor(white) lcolor(white))

/* Figure A3b */
qui margins, dydx(leftexec2l1) at(top10isl1=(26(2)48)) atmeans
marginsplot, xsize(4) ysize(6) addplot(hist top10isl1 if top10isl1<48 & top10isl1>26 & top_incrate_nl1!=., yaxis(2) xscale(range(26(2)48)) yscale(range(-1(2)8)) yline(0) ylabel(0(2)8) yscale(axis(2) range(0 .21) off) xlabel(26(2)48) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) legend(off) xtitle("Top 10% Income Share") ytitle("") title("") graphregion(fcolor(white) lcolor(white))


**** U.S. Senate Analyses ****

clear
use "Senate Data.dta" 

/** Table 2 **/
/* Model 3 */
logit vote1 c.top1is##c.republican independent dwnom1 i.year i.state, cluster(state)

/* Model 4 */
logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

/* Model 5 */
logit vote1 c.top1is##c.dwnom1 republican independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

/* Model 6 */
logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

/** Figure 3a **/
qui logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)
qui margins if e(sample), dydx(c.top1is) at(c.republican=(0(1)1) independent=0)
marginsplot

/** Figure 3b **/
qui logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)
qui margins if e(sample), at(top1is=(5(5)50) republican==1 independent=0)
marginsplot, addplot(hist top1is if e(sample) & republican==1 & independent==0 & top1is<50.01, yaxis(2) xscale(range(5(5)50)) xlabel(5(5)50) ylabel() yscale(axis(2) range(0 .15) off) lc(white%0) fcolor(gs10%25) recast(rarea)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(State Top 1% Income Share) title("") ytitle(Predicted Probability of Pro-Income Tax Vote) legend(off) graphregion(fcolor(white) lcolor(white))

/** Figure 4a **/
qui logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)
qui margins if e(sample), dydx(top1is) at(dwnom1=(-1(0.25)1.25) republican==0 independent==0) atmean
marginsplot, addplot(hist dwnom1 if republican==0 & independent==0, yaxis(2) xscale(range(-1(0.25)1.25)) xlabel(-1(0.25)1.25) yscale(range(0.06(.02).04)) ylabel(-0.06(.02).04) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(DW-NOMINATE 1) title("") yline(0) ytitle(Marginal Effect of Top 1% Income Share) legend(off) graphregion(fcolor(white) lcolor(white))

/** Figure 4b **/
qui logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)
qui margins if e(sample), dydx(top1is) at(dwnom1=(-1.25(0.25)1.25) republican==1 independent==0) atmean
marginsplot, addplot(hist dwnom1 if c.republican==1 & independent==0, yaxis(2) xscale(range(-1.25(0.25)1.25)) xlabel(-1(0.25)1.25) yscale(range(0.06(.02).04)) ylabel(-0.06(.02).04) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(DW-NOMINATE 1) title("") yline(0) ytitle(Marginal Effect of Top 1% Income Share) legend(off) graphregion(fcolor(white) lcolor(white))

/** Figure 5a **/
qui logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)
qui margins if e(sample), at(top1is==(6(2)30) dwnom1=-.5 republican==0 independent==0) atmean
marginsplot, addplot(hist top1is if e(sample) & top1is<=30 & top1is>=6, yaxis(2) xscale(range(6(3)30)) xlabel(6(3)30) yscale(range(0(.25)1)) ylabel(0(.25)1) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(Top 1% Income Share) title("") ytitle(Predicted Probability of Pro-Income Tax Vote) legend(off) graphregion(fcolor(white) lcolor(white))

/** Figure 5b **/
qui logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)
qui margins if e(sample), at(top1is==(6(2)30) dwnom1=.25 republican==0 independent==0) atmean
marginsplot, addplot(hist top1is if e(sample) & top1is<=30 & top1is>=6, yaxis(2) xscale(range(6(3)30)) xlabel(6(3)30) yscale(range(0(.25)1)) ylabel(0(.25)1) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(Top 1% Income Share) title("") ytitle(Predicted Probability of Pro-Income Tax Vote) legend(off) graphregion(fcolor(white) lcolor(white))

/** Table A2 **/
qui logit vote1 c.top1is##c.republican independent dwnom1 i.year i.state, cluster(state)
sutex vote1 top1is top10is republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried services_log gdpgrowth lngdppc cpimw100 union ln_statespend  if e(sample)

/** Table A9 **/
logit vote1 c.top1is##c.republican independent dwnom1 i.year i.state i.bill, cluster(state)

logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried i.year i.state i.bill, cluster(state)

logit vote1 c.top1is##c.dwnom1 republican independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state i.bill, cluster(state)

logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state i.bill, cluster(state)

/** Table A10 **/
logit vote2 c.top1is##c.republican independent dwnom1 i.year i.state, cluster(state)

logit vote2 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

logit vote2 c.top1is##c.dwnom1 republican independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

logit vote2 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

/** Table A11 **/
logit vote1 c.top10is##c.republican independent dwnom1 i.year i.state, cluster(state)

logit vote1 c.top10is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

logit vote1 c.top10is##c.dwnom1 republican independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

logit vote1 c.top10is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried i.year i.state, cluster(state)

/** Table A12 **/
logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate i.year i.state, cluster(state)

logit vote1 c.top1is##c.dwnom1 republican independent ln_population per_fb mobrate i.year i.state, cluster(state)

logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate i.year i.state, cluster(state)

/** Table A13 **/
logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried services_log gdpgrowth lngdppc cpimw100 union ln_statespend i.year i.state, cluster(state)

logit vote1 c.top1is##c.dwnom1 republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried services_log gdpgrowth lngdppc cpimw100 union ln_statespend i.year i.state, cluster(state)

logit vote1 c.top1is##c.republican##c.dwnom1 independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried services_log gdpgrowth lngdppc cpimw100 union ln_statespend i.year i.state, cluster(state)

/** Table A14 **/
logit vote1 c.top1is##c.republican independent dwnom1 ln_population per_fb mobrate ln_farms ln_salaried democrat_s i.year i.state, cluster(state)

logit vote1 c.top1is##c.dwnom1 republican independent ln_population per_fb mobrate ln_farms ln_salaried democrat_s i.year i.state, cluster(state)

logit vote1 c.top1is##c.republican##c.dwnom1 independent ln_population per_fb mobrate ln_farms ln_salaried democrat_s i.year i.state, cluster(state)

/** Table A15 **/
logit vote1 c.top1is##c.republican c.dwnom1 independent i.year i.state if year>1971, cluster(state)

logit vote1 c.top1is##c.republican##c.dwnom1 independent i.year i.state if year>1971, cluster(state)

/** Figure A4 **/
qui margins if e(sample), dydx(top1is) at(dwnom1=(-1(0.25)1.25) republican==0 independent==0) atmean
marginsplot, addplot(hist dwnom1 if republican==0 & independent==0, yaxis(2) xscale(range(-1(0.25)1.25)) xlabel(-1(0.25)1.25) yscale(range(-.1(0.05)0.05)) ylabel(-.1(0.05)0.05) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(DW-NOMINATE 1) title("") yline(0) ytitle(Marginal Effect of Top 1% Income Share) legend(off) graphregion(fcolor(white) lcolor(white))
qui margins if e(sample), dydx(top1is) at(dwnom1=(-1.25(0.25)1.25) republican==1 independent==0) atmean
marginsplot, addplot(hist dwnom1 if c.republican==1 & independent==0, yaxis(2) xscale(range(-1.25(0.25)1.25)) xlabel(-1(0.25)1.25) yscale(range(-.1(0.05)0.05)) ylabel(-.1(0.05)0.05) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(DW-NOMINATE 1) title("") yline(0) ytitle(Marginal Effect of Top 1% Income Share) legend(off) graphregion(fcolor(white) lcolor(white))

/** Figure A5 **/

qui margins if e(sample), at(top1is==(6(2)30) dwnom1=-.5 republican==0 independent==0) atmean
marginsplot, addplot(hist top1is if e(sample) & top1is<=30 & top1is>=6, yaxis(2) xscale(range(6(3)30)) xlabel(6(3)30) yscale(range(0(0.25)1)) ylabel(0(0.25)1) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(Top 1% Income Share) title("") ytitle(Predicted Probability of Pro-Income Tax Vote) legend(off) graphregion(fcolor(white) lcolor(white))
qui margins if e(sample), at(top1is==(6(2)30) dwnom1=.25 republican==0 independent==0) atmean
marginsplot, addplot(hist top1is if e(sample) & top1is<=30 & top1is>=6, yaxis(2) xscale(range(6(3)30)) xlabel(6(3)30) yscale(range(0(0.25)1)) ylabel(0(0.25)1) yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(gs10%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(emidblue%30) lc(white%0)) xtitle(Top 1% Income Share) title("") ytitle(Predicted Probability of Pro-Income Tax Vote) legend(off) graphregion(fcolor(white) lcolor(white))
